// Fix: Grid notation      Labels


/*
QUERY: select floor(deweyClass) as deweyCl,HOUR(cout) as hour, count(*) from inraw where deweyClass != 'null'
and month(cout) = '04' and date(cout) != '1970-01-01' group by deweyCl order by deweyCl;
*/


// The scale of our world
float zoom;
// A vector to store the offset from the center
PVector offset;
// The previous offset
PVector poffset;
// A vector for the mouse position
PVector mouse;

PFont font1 = createFont("Helvetica", 15); 
PFont font2 = createFont("Helvetica", 30);
int border = 20;
int[][] hourCoutByDewey = new int[1000][24];  //[dewey][hour]
int[][] tempArray = new int[1000][24];  //[dewey][hour]
int displayMode = 0;

boolean showGrid = false;
boolean showMousePosition = false;
int padding = 10;
int boxSize = 6;

float xScalar = 0.6; 
float yScalar = 20;  
float labelSpacing = yScalar;
float mouseYScalar = 0.4;
float mouseXScalar = 1.66;
float alphaScalar = 0.3;
float offsetX = -250;
float offsetY = -280;

/*
float horizontalGridDivisions = 8;
float verticalGridDivisions = 8;
*/
float horizontalSquareSize;
float verticalSquareSize;

void setup() {
  size(800, 600);
  zoom = 1.0;
  offset = new PVector(0, 0);
  poffset = new PVector(0, 0);
/*
  horizontalSquareSize = width/horizontalGridDivisions;
  verticalSquareSize = height/verticalGridDivisions;
*/  
  colorMode(HSB, 360,100,100); //color mode- like RGB or HSB (learn to use HSB because it's the best: http://en.wikipedia.org/wiki/HSL_and_HSV)
  smooth();

  //import the data from our text file 
  String savedData[] = loadStrings("savedData.txt");
  println("QUERY: " + savedData[0]);

  int curDewey = 1;
  int oldDewey = 1;
  int curHour = 0;

  for (int i=1; i < savedData.length; i++) {
    String temp[] = split(savedData[i], ",");
    curDewey = Integer.parseInt(temp[0]);
    curHour = Integer.parseInt(temp[1]);
    tempArray[curDewey][curHour]=Integer.parseInt(temp[2]);
    hourCoutByDewey[curDewey][curHour]=hourCoutByDewey[curDewey][curHour]+tempArray[curDewey][curHour]; // sum values    
  }
  /*
  //test
for (int i=1; i < 1000; i++) {
    println(hourCoutByDewey[i][12]); // sum values    
//    println(hourCoutByDewey[i][9]); // sum values    
  }  
  */
}

void draw() {
    int rectOffset = boxSize/2;
    background(340);
       pushMatrix();
    if(showGrid == true){
      //drawGrid();
    }
    if(showMousePosition == true){
      drawMouse();
    }
     
    
    // Everything must be drawn relative to center
    translate(width/2, height/2);
    // Use scale for 2D "zoom"
    scale(zoom);
    // The offset (note how we scale according to the zoom)
    translate(offset.x/zoom, offset.y/zoom);
  
    //draw transactions
    strokeWeight(1.0);
    strokeCap(SQUARE);
    fill(220,100,150,150);  
    for(int i = 0;i<1000;i++){  // loop through dewey classes
      for(int j = 0;j<24;j++){  // loop through dewey classes
        //float tempX = (i*(width-horizontalSquareSize)/100)+padding; 
        if(hourCoutByDewey[i][j]!=0) {
          stroke(100,0,200,hourCoutByDewey[i][j]*alphaScalar);
          rect(i*xScalar+offsetX,j*yScalar+offsetY,boxSize,boxSize);
        //rect(height-padding-hourCoutByDewey[i][j]*scalar, boxSize, boxSize); 
        //line(tempX, height-padding, tempX, height-padding-hourCoutByDewey[i]*scalar);
        }
      }
    }
    
    //draw attached horizontal labels
    textAlign(RIGHT,CENTER);
    textSize(13);

    fill(10,135,40,140);  

    for(int i = 0;i<21;i++){
        if(i>6){
           if(i<=11){
             text("a.m.", -270, (i*labelSpacing)+offsetY);       
           }
           if(i>11) {
              text("p.m.", -270, (i*labelSpacing)+offsetY);       
           }
           if(i>12) {
             text(i-12, -300, (i*labelSpacing)+offsetY);
           }
           else if(i<20) {
             text(i, -300, (i*labelSpacing)+offsetY);   
           }
        }
    }

    textSize(15);
    text("Hours",-330,0); 
    text("Dewey Categories",55,175);
    text("April 12, 2011",45, 195);
     
    popMatrix();
  
  // Draw text not panned / zoomed
    fill(10,235,40, 140);  
    textAlign(LEFT,TOP);
    textSize(18);
    text("Transactions Plotted by Hour and Dewey Categories",200,padding);
    textSize(15);
    text("David Gordon",padding+20,height-padding-60);
    text("MAT 259: Visualizing Data, Winter 2012",padding+20,height-padding-30);
    textSize(12);
    text("* Click to see Dewey number",300,65);
}

void drawMouse(){
  /*
    // Everything must be drawn relative to center
    translate(width/2, height/2);
  
    // Use scale for 2D "zoom"
    scale(zoom);
    // The offset (note how we scale according to the zoom)
    translate(offset.x/zoom, offset.y/zoom);

  */
  
  float cursorX = mouse.x-offset.x;
  float cursorY = mouse.y-offset.y;
    
  stroke(0,0,70);
  strokeWeight(1.0);

  if( (cursorX*mouseXScalar-252)>0 && (cursorX*mouseXScalar-252) < 1000)
  {
    line(mouse.x,height,mouse.x,0);
    textAlign(LEFT,BOTTOM);
    textFont(font1);
    
/*   println("offset.y:");
     println(offset.y);
*/    
    if((cursorX*mouseXScalar-252)>0){                // fix this
      text(round(cursorX*mouseXScalar-252),cursorX-60, cursorY-30); 
    }
  }
}


void keyPressed(){
 //press spacebar to toggle the grid on and off  
 if(key == ' '){
   if(showGrid == true){
     showGrid = false;
   }
   //else{showGrid = true;}
 } 
 /*
 if (key == 'a') {
    zoom += 0.1;
  } 
  else if (key == 'z') {
    zoom -= 0.1;
  }
  zoom = constrain(zoom,0,100);
  */
}

void mousePressed(){
  // Store the mouse and the previous offset

  mouse = new PVector(mouseX, mouseY);
  poffset.set(offset);
 
  if(showMousePosition == true){
     showMousePosition = false;
   }
   else{showMousePosition = true;}
   
}


// Calculate the new offset based on change in mouse vs. previous offsey
void mouseDragged() {
//  offset.x = mouseX - mouse.x + poffset.x;
//  offset.y = mouseY - mouse.y + poffset.y;
}

